

# YOUTUBE API
YouTube Web API 

## Authors
- [@Deno9099(WNE9838) - Nguyễn Văn Vinh](https://pypi.org/user/deno9099/)

##
[![YouTube](https://upload.wikimedia.org/wikipedia/commons/b/b8/YouTube_Logo_2017.svg)](https://www.youtube.com/@wne9838)

## Cách Cài

Install YouTube Web API with python

```python
  pip install youtube_web_api
  pip3 install youtube_web_api
```
## Chức năng
- Subcribe,Comment kênh youtube khác với cookies và requests
- Phù hợp cho những người làm tool
## Cách Sử Dụng
```python
import youtube_web_api
youtube_web_api.YouTube_Api(cookies,x_browser_validation,x_client_data,x_goog_visitor_id,user_agent)
```
- Cookies : là cookies trong tài khoản youtube của bạn đây là tham số cố định
- Ngoài cookies thì các tham số khác không cần truyền coi như mặc định
## Lưu Ý
- Youtube của tài khoản lấy cookies phải để Tiếng Anh(EN)
- Nếu không chạy được thì nên truyền lại các tham số còn lại đó vì tham số mặc định có thể quá cũ hoặc bị lỗi
## Hỗ trợ
Vui lòng liên hệ qua email [vinhytb3010@gmail.com]()(mailto:vinhytb3010@gmail.com) hoặc hỗ trợ qua các nền tảng của tác giả trực thuộc.
## 🔗 Links
[![YouTube](https://img.shields.io/badge/YouTube-FF0000?style=for-the-badge&logo=youtube&logoColor=white)](https://www.youtube.com/@wne9838)
[![GitHub](https://img.shields.io/badge/GitHub-181717?style=for-the-badge&logo=github&logoColor=white)](https://github.com/deno4908)
